@@ -1,8 +1,11 @@
 package Weed::FieldTypes::SFString;
 
+our $VERSION = '0.0078';
+
 use Weed 'SFString : X3DField { "" }';
 
 use Unicode::String;
+#Text::Unidecode;
 
 use overload
   'int' => sub { length $_[0]->getValue },
@@ -11,7 +14,7 @@ use overload
 
 sub setValue {
 	my ( $this, $value ) = @_;
-	$this->X3DField::setValue( defined $value ? "$value" : $this->getInitialValue );
+	$this->X3DField::setValue( defined $value ? "$value" : $this->getDefaultValue );
 }
 
 sub toString { sprintf "%s", $_[0]->getValue }
