@@ -1,7 +1,7 @@
 package Weed::Parse::Float;
 use Weed::Perl;
 
-our $VERSION = '0.001';
+our $VERSION = '0.0002';
 
 use Weed::RegularExpressions qw.$_float $_nan $_inf.;
 
@@ -12,8 +12,8 @@ our @EXPORT_OK = qw.parseFloat float.;
 sub parseFloat { &float( \$_[0] ) }
 
 sub float {
-	return 0 + $1 if ${ $_[0] } =~ m.$_float.gc;
-	return 0      if ${ $_[0] } =~ m.$_nan.gc;
+	return $1 if ${$_[0]} =~ m.$_float.gc;
+	return 0  if ${$_[0]} =~ m.$_nan.gc;
 	#return ...  if $$string =~ m.$_inf.gc;
 	#X3DError::Debug "VRML2::Parser::float undef\n";
 	return;
